@@ -10,26 +10,41 @@ import mimetypes
 import dash_renderer
 import dash_core_components as dcc
 
-from dash._utils import stringify_id
+from dash.version import __version__
+from dash._utils import (
+    stringify_id,
+    format_tag
+)
 
 from .utilities import (
     BASE_API_URL,
     call_get_requests
 )
 
+_app_entry = """
+    <main id="AnalyticsAppsUI-container">
+    </main>
+"""
+
+_report_content_entry_id_ = 'AnalyticsAppsUI-report-container'
+_report_sidebar_entry_id_ = 'AnalyticsAppsUI-sidebar-container'
+
 class OAPDash(dash.Dash):
     static_files = {
         'css': [
-            'bootstrap.min.css'
+            # 'bootstrap.min.css',
+            'main.wrapper.css'
         ],
-        'js': [ ]
+        'js': [
+            'main.wrapper.js'
+        ]
     }
 
     def __init__(self, **kwargs):
         self.route = kwargs.pop('route')
-        route_prefix = '/'+self.route if self.route else ''
+        route_prefix = f'/{self.route}' if self.route else ''
         # assume this is not set by user
-        kwargs['requests_pathname_prefix'] = route_prefix + '/'
+        kwargs['requests_pathname_prefix'] = f'{route_prefix}/'
 
         super(OAPDash, self).__init__(**kwargs)
 
@@ -39,6 +54,23 @@ class OAPDash(dash.Dash):
         """
         super(OAPDash, self).init_app(app)
 
+        # serve the wrapper's media
+        assets_folder = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)), 'analysis-wrapper'
+        )
+
+        self.server.register_blueprint(
+            flask.Blueprint(
+                'analytics_sdk_assets',
+                self.config.name,
+                static_folder=assets_folder,
+                static_url_path="{}{}".format(
+                    self.config.routes_pathname_prefix,
+                    'wrapper-static',
+                )
+            )
+        )
+
         # register manifest file
         self._add_url("opsramp-analytics-utils/<string:file_name>", self.serve_resource)
         self._add_url("asset-manifest.json", self.serve_manifest)
@@ -49,8 +81,49 @@ class OAPDash(dash.Dash):
 
         return res.status_code == 200
 
+    def _index(self, *args, **kwargs):  # pylint: disable=unused-argument
+        scripts = self._generate_scripts_html()
+        css = self._generate_css_dist_html()
+        config = self._generate_config_html()
+        metas = self._generate_meta_html()
+        renderer = self._generate_renderer()
+
+        # use self.title instead of app.config.title for backwards compatibility
+        title = self.title
+
+        if self._favicon:
+            favicon_mod_time = os.path.getmtime(
+                os.path.join(self.config.assets_folder, self._favicon)
+            )
+            favicon_url = self.get_asset_url(self._favicon) + "?m={}".format(
+                favicon_mod_time
+            )
+        else:
+            favicon_url = "{}_favicon.ico?v={}".format(
+                self.config.requests_pathname_prefix, __version__
+            )
+
+        favicon = format_tag(
+            "link",
+            {"rel": "icon", "type": "image/x-icon", "href": favicon_url},
+            opened=True,
+        )
+
+        index = self.interpolate_index(
+            metas=metas,
+            title=title,
+            css=css,
+            config=config,
+            scripts=scripts,
+            app_entry=_app_entry,
+            favicon=favicon,
+            renderer=renderer,
+        )
+
+        return index
+
     def index(self, *args, **kwargs):  # pylint: disable=unused-argument
-        index = super(OAPDash, self).index(args, kwargs)
+        index = self._index(args, kwargs)
 
         # check auth
         REQUIRE_AUTH_REDIRECT = os.getenv('REQUIRE_AUTH_REDIRECT') == 'true'
@@ -58,16 +131,16 @@ class OAPDash(dash.Dash):
             return index
         else:
             PLATFORM_ROUTE = os.getenv("PLATFORM_ROUTE", '')
-            redirect_url = f"https://localhost/tenancy/web/login?cb=/{PLATFORM_ROUTE}"
+            redirect_url = f"/tenancy/web/login?cb=/{PLATFORM_ROUTE}"
 
             return flask.redirect(redirect_url, code=302)
 
     def serve_manifest(self):
         return {
             "files": {
-                "main.css": "/main.css",
-                "main.js": "/main.js",
-                "main.js.map": "/analytics-apps/static/js/main.b42d7633.js.map",
+                "main.css": "/analytics-apps/opsramp-analytics-utils/main.css",
+                "main.js": "/analytics-apps/opsramp-analytics-utils/main.js",
+                # "main.js.map": "/analytics-apps/static/js/main.b42d7633.js.map",
                 "index.html": "/analytics-apps/index.html",
             },
             "entrypoints": [
@@ -81,8 +154,8 @@ class OAPDash(dash.Dash):
             return self._serve_main_css()
         elif file_name == 'main.js':
             return self._serve_main_js()
-        elif file_name == 'dummy_dash_renderer.js':
-            return ''
+        elif file_name == 'report_main.js':
+            return self._serve_report_main_js()
         else:
             extension = "." + file_name.split(".")[-1]
             mimetype = mimetypes.types_map.get(extension, "application/octet-stream")
@@ -99,7 +172,8 @@ class OAPDash(dash.Dash):
 
         # oap css files
         for file_path in self.static_files['css']:
-            body += pkgutil.get_data('analytics_sdk', 'assets/'+file_path).decode("utf-8")
+            body += pkgutil.get_data('analytics_sdk', 'analysis-wrapper/'+file_path).decode("utf-8")
+        body = body.replace('url(/static/media', f'url({self.config.requests_pathname_prefix}wrapper-static/media')
 
         # custom css files
         for resource in self.css.get_all_css():
@@ -111,6 +185,11 @@ class OAPDash(dash.Dash):
         return response
 
     def _serve_main_js(self):
+        body = pkgutil.get_data('analytics_sdk', 'analysis-wrapper/main.js').decode("utf-8")
+        response = flask.Response(body, mimetype='application/javascript')
+        return response
+    def _serve_report_main_js(self):
+        dev = self._dev_tools.serve_dev_bundles
         body = f"var oap_config = {json.dumps(self._config(), cls=plotly.utils.PlotlyJSONEncoder)};\n"
 
         # external js files
@@ -121,8 +200,10 @@ class OAPDash(dash.Dash):
         # self._inline_scripts
 
         # oap js files
-        for file_path in self.static_files['js']:
-            body += pkgutil.get_data('analytics_sdk', 'assets/'+file_path).decode("utf-8")
+        if os.getenv("INCLUDE_WRAPPER") == "true":
+            for file_path in self.static_files['js']:
+                _body = pkgutil.get_data('analytics_sdk', 'analysis-wrapper/'+file_path).decode("utf-8")
+                body += self.pre_process(_body, file_path, dev)
 
         # system js files
         mode = "dev" if self._dev_tools["props_check"] is True else "prod"
@@ -135,8 +216,6 @@ class OAPDash(dash.Dash):
 
             deps.append(dep)
 
-        dev = self._dev_tools.serve_dev_bundles
-
         resources = (
             self.scripts._resources._filter_resources(deps, dev_bundles=dev)
           + self.scripts.get_all_scripts(dev_bundles=dev)
@@ -168,8 +247,6 @@ class OAPDash(dash.Dash):
             #     # Add a cache-busting query param
             #     srcs.append(static_url)
 
-        # from pprint import pprint
-        # import pdb;pdb.set_trace()
         body += "var renderer = new DashRenderer();"
         response = flask.Response(body, mimetype='application/javascript')
 
@@ -178,7 +255,11 @@ class OAPDash(dash.Dash):
     def pre_process(self, txt_body, file_name, dev):
         if file_name.startswith('dash_renderer.'):
             txt_body = txt_body.replace("JSON.parse(document.getElementById('_dash-config').textContent);", "oap_config;")
-            txt_body = txt_body.replace('JSON.parse(document.getElementById("_dash-config").textContent);', 'oap_config;')
+            txt_body = txt_body.replace('react-entry-point', _report_content_entry_id_)
+        elif file_name == 'main.wrapper.js':
+            static_media_path = f'{self.config.requests_pathname_prefix.lstrip("/")}wrapper-static/media/'
+            txt_body = txt_body.replace('static/media/', static_media_path)
+            txt_body = txt_body.replace('getElementById("root")', f'getElementById("{_report_sidebar_entry_id_}")')
 
         return txt_body + "\n"
 
@@ -204,17 +285,16 @@ class OAPDash(dash.Dash):
             _layout.children.append(dcc.Store(id="dummy-store"))
             _layout.children.append(dcc.Store(id=out_store_id, storage_type="local"))
             _layout.children.append(dcc.Store(id=in_store_id, storage_type="local"))
+            _layout.children.append(dcc.Store(id='op-filter-start-date', storage_type="local"))
+            _layout.children.append(dcc.Store(id='op-filter-end-date'))
 
         return _layout
 
     def _generate_renderer(self):
-        return f"""
-            <script id="_dash-renderer" type="application/javascript"></script>
-            <script src="{self.config.requests_pathname_prefix}opsramp-analytics-utils/dummy_dash_renderer.js"></script>
-        """
+        return ''
 
     def _generate_config_html(self):
-        return '<script id="_dash-config" type="application/json"></script>'
+        return ''
 
     def _generate_css_dist_html(self):
         return f'<link rel="stylesheet" href="{self.config.requests_pathname_prefix}opsramp-analytics-utils/main.css">'
